==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WeightedCloseIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { WeightedCloseIndicatorDescription } from "./WeightedCloseIndicatorDescription";
/**
 * @hidden
 */
export let WeightedCloseIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class WeightedCloseIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (WeightedCloseIndicatorDescriptionMetadata.a == null) {
                WeightedCloseIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WeightedCloseIndicatorDescriptionMetadata.c(WeightedCloseIndicatorDescriptionMetadata.a);
            }
            if (a.k(WeightedCloseIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(WeightedCloseIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            WeightedCloseIndicatorDescriptionMetadata.b(a);
            a.ad("WeightedCloseIndicator", () => new WeightedCloseIndicatorDescription());
            a.ac("WeightedCloseIndicator", WeightedCloseIndicatorDescriptionMetadata.a);
        }
    }
    WeightedCloseIndicatorDescriptionMetadata.$t = markType(WeightedCloseIndicatorDescriptionMetadata, 'WeightedCloseIndicatorDescriptionMetadata');
    WeightedCloseIndicatorDescriptionMetadata.a = null;
    return WeightedCloseIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WeightedCloseIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { WeightedCloseIndicatorDescription } from "./WeightedCloseIndicatorDescription";
/**
 * @hidden
 */
export let WeightedCloseIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class WeightedCloseIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (WeightedCloseIndicatorDescriptionMetadata.a == null) {
                WeightedCloseIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WeightedCloseIndicatorDescriptionMetadata.c(WeightedCloseIndicatorDescriptionMetadata.a);
            }
            if (a.k(WeightedCloseIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(WeightedCloseIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            WeightedCloseIndicatorDescriptionMetadata.b(a);
            a.ae("WeightedCloseIndicator", () => new WeightedCloseIndicatorDescription());
            a.ad("WeightedCloseIndicator", WeightedCloseIndicatorDescriptionMetadata.a);
        }
    }
    WeightedCloseIndicatorDescriptionMetadata.$t = markType(WeightedCloseIndicatorDescriptionMetadata, 'WeightedCloseIndicatorDescriptionMetadata');
    WeightedCloseIndicatorDescriptionMetadata.a = null;
    return WeightedCloseIndicatorDescriptionMetadata;
})();
